<?php

// The content width.
if ( ! isset( $content_width ) ) 
	$content_width = 650; 
		
// Register navigation menu.
register_nav_menu('topnav', __('Navigation', 'zwei-seiten'));

// Enable post and comment RSS feed links to head.
add_theme_support('automatic-feed-links');
		
// Enable post-thumbnail support for a Theme.
add_theme_support('post-thumbnails');

// Add support for Custom backgrounds.
add_custom_background();

// Add callback for custom TinyMCE editor stylesheets.
add_editor_style();
		
// Main Widget Area
register_sidebar(array(
	'name' => __('Primary', 'zwei-seiten'),
	'id' => 'primary',
	'description' => __('Main Widget Area', 'zwei-seiten'),
	'before_widget' => '<div id="%1$s" class="widget %2$s">',
	'after_widget' => '</div>',
	'before_title' => '<h3 class="widget-title">',
	'after_title' => '</h3>'
));
		
// Make theme available for translation.
// Translations can be added to the /languages/ directory.
load_theme_textdomain('zwei-seiten', get_template_directory() . '/languages');
		
// Add callbacks for image header display.
define('HEADER_TEXTCOLOR', '999999');
define('HEADER_IMAGE', ''); // %s is the template dir uri
define('HEADER_IMAGE_WIDTH', 940); 
define('HEADER_IMAGE_HEIGHT', 180); // use width and height appropriate for your theme
define('NO_HEADER_TEXT', false);
		
add_custom_image_header('zweiseiten_header_style', 'zweiseiten_admin_header_style');

function zweiseiten_header_style() {
	if(HEADER_TEXTCOLOR == get_header_textcolor())
		return;
	?>
	<style type="text/css">
		<?php if('blank' == get_header_textcolor()) : ?>
	#header h1,
	#header p {
		position: absolute !important;
		clip: rect(1px 1px 1px 1px); /* IE6, IE7 */
		clip: rect(1px, 1px, 1px, 1px);
	}
		<?php else : ?>
	#header h1 a,
	#header p {
		color: #<?php echo get_header_textcolor(); ?> !important;
	}
		<?php endif; ?>
		</style>
	<?php 
}
	
// Gets included in the admin header
function zweiseiten_admin_header_style() {
	?><style type="text/css">
			<?php if(get_header_textcolor() != HEADER_TEXTCOLOR) : ?>
		#header h1 a,
		#header p {
			color: #<?php echo get_header_textcolor(); ?>;
		}
			<?php endif; ?>
		#headimg img {
			width: <?php echo HEADER_IMAGE_WIDTH; ?>px;
			height: <?php echo HEADER_IMAGE_HEIGHT; ?>px;
			margin: 0;
		}
	</style>
<?php 
}

// Returns a "Continue Reading" link for excerpts.
function zweiseiten_continue_reading_link() {
	return ' <a href="'. esc_url( get_permalink() ) . '">' . __('<span class="custom-more">Continue reading &rarr;</span>', 'zwei-seiten') . '</a>';
}

// Replaces "[...]" with an ellipsis and zweiseiten_continue_reading_link().
function zweiseiten_auto_excerpt_more($more) {
	return ' &hellip;' . zweiseiten_continue_reading_link();
}
add_filter('excerpt_more', 'zweiseiten_auto_excerpt_more');

/**
 * Template for comments and pingbacks.
 * Taken from Twenty Ten Theme.
 */
function zweiseiten_comment($comment, $args, $depth) {
	$GLOBALS['comment'] = $comment;
	switch ( $comment->comment_type ) :
		case '' :
	?>
	<li <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>">
		<div id="comment-<?php comment_ID(); ?>">
		<div class="comment-author vcard">
			<?php echo get_avatar($comment, 50); ?>
			<?php printf(__( '%s <span class="says">says:</span>', 'zwei-seiten'), sprintf('<cite class="fn">%s</cite>', get_comment_author_link())); ?>
		</div><!-- end: .comment-author .vcard -->
		<?php if($comment->comment_approved == '0') : ?>
			<em class="comment-awaiting-moderation"><?php _e('Your comment is awaiting moderation.', 'zwei-seiten'); ?></em>
			<br />
		<?php endif; ?>

		<div class="comment-meta commentmetadata"><a href="<?php echo esc_url(get_comment_link($comment->comment_ID)); ?>">
			<?php printf(__('%1$s at %2$s', 'zwei-seiten'), get_comment_date(),  get_comment_time() ); ?></a><?php edit_comment_link(__( '(Edit)', 'zwei-seiten'), ' ' ); ?>
		</div><!-- end: .comment-meta .commentmetadata -->

		<div class="comment-body"><?php comment_text(); ?></div>

		<div class="reply">
			<?php comment_reply_link( array_merge($args, array('depth' => $depth, 'max_depth' => $args['max_depth'])) ); ?>
		</div><!-- end: .reply -->
	</div><!-- end: #comment -->

	<?php
			break;
		case 'pingback'  :
		case 'trackback' :
	?>
	<li class="post-pingback">
		<p><?php _e('Pingback:', 'zwei-seiten'); ?> <?php comment_author_link(); ?><?php edit_comment_link(__( '(Edit)', 'zwei-seiten'), ' '); ?></p>
	<?php
			break;
	endswitch;
}

// Register JS
function zweiseiten_js_init() {
	if(!is_admin()) {
		wp_deregister_script('jquery');
		wp_register_script('jquery', 'https://ajax.googleapis.com/ajax/libs/jquery/1.6.2/jquery.min.js', false, '1.6.2');
		wp_enqueue_script('jquery');
		wp_enqueue_script('zweiseiten_navmenu', get_template_directory_uri() . '/js/navmenu.js', array('jquery'), false, true);
	}
}
add_action('wp_enqueue_scripts', 'zweiseiten_js_init');

// Load up our theme options.
require_once(get_stylesheet_directory() . '/theme-options.php');

// Custom CSS 
function zweiseiten_custom_css() {
	$options = get_option('zweiseiten_options');
	if($options['zs_custom_css'] !='') : ?>
		<style type="text/css">
			<?php echo $options['zs_custom_css']; ?>;
		</style>
	<?php endif;
}
add_action('wp_head', 'zweiseiten_custom_css');

?>