<?php

add_action( 'admin_init', 'zweiseiten_options_init' );
add_action( 'admin_menu', 'zweiseiten_options_add_page' );

/**
 * Init plugin options to white list our options
 */
function zweiseiten_options_init(){
	register_setting( 'zweiseiten_options_group', 'zweiseiten_options', 'zweiseiten_options_validate' );
}

/**
 * Fix the edit_theme_options/manage_options bug.
 * http://make.wordpress.org/themes/2011/07/01/wordpress-3-2-fixing-the-edit_theme_optionsmanage_options-bug/
 */
function zweiseiten_get_options_page_cap() {
    return 'edit_theme_options';
}

add_filter('option_page_capability_zweiseiten_options', 'zweiseiten_get_options_page_cap');

/**
 * Load up the menu page
 */
function zweiseiten_options_add_page() {
	add_theme_page( __( 'Theme Options', 'zwei-seiten' ), __( 'Theme Options', 'zwei-seiten' ), zweiseiten_get_options_page_cap(), 'zweiseiten_options', 'zweiseiten_options_do_page' );
}	

/**
 * Create the options page
 */
function zweiseiten_options_do_page() {

	if ( ! isset( $_REQUEST['settings-updated'] ) )
		$_REQUEST['settings-updated'] = false;

	?>
	<div class="wrap">
		<?php screen_icon(); echo "<h2>" . get_current_theme() . __( ' Theme Options', 'zwei-seiten' ) . "</h2>"; ?>

		<?php if ( false !== $_REQUEST['settings-updated'] ) : ?>
		<div class="updated fade"><p><strong><?php _e( 'Options saved', 'zwei-seiten' ); ?></strong></p></div>
		<?php endif; ?>

		<form method="post" action="options.php">
			<?php settings_fields('zweiseiten_options_group'); ?>
			<?php $options = get_option('zweiseiten_options'); ?>

			<table class="form-table">
			
				<?php
				/**
				 * Search Box In Header
				 */
				?>
				<tr valign="top"><th scope="row"><?php _e( 'Display Search Box In Header?', 'zwei-seiten' ); ?></th>
					<td>
						<input id="zweiseiten_options[zs_search_on]" name="zweiseiten_options[zs_search_on]" type="checkbox" value="1" <?php checked( '1', $options['zs_search_on'] ); ?> />
						<label class="description" for="zweiseiten_options[zs_search_on]"><?php _e( 'Hidden by default.', 'zwei-seiten' ); ?></label>
					</td>
				</tr>

				<?php
				/**
				 * Social Media
				 */
				?>
				<tr valign="top"><th scope="row"><?php _e( 'RSS', 'zwei-seiten' ); ?></th>
					<td>
						<input id="zweiseiten_options[zs_rss_url]" class="regular-text" type="text" name="zweiseiten_options[zs_rss_url]" value="<?php esc_attr_e( $options['zs_rss_url'] ); ?>" />
						<label class="description" for="zweiseiten_options[zs_rss_url]"><?php _e( 'Enter your RSS Feed URL.', 'zwei-seiten' ); ?></label>
					</td>
				</tr>

				<tr valign="top"><th scope="row"><?php _e( 'Twitter', 'zwei-seiten' ); ?></th>
					<td>
						<input id="zweiseiten_options[zs_twitter_url]" class="regular-text" type="text" name="zweiseiten_options[zs_twitter_url]" value="<?php esc_attr_e( $options['zs_twitter_url'] ); ?>" />
						<label class="description" for="zweiseiten_options[zs_twitter_url]"><?php _e( 'Enter your Twitter URL.', 'zwei-seiten' ); ?></label>
					</td>
				</tr>

				<tr valign="top"><th scope="row"><?php _e( 'Facebook', 'zwei-seiten' ); ?></th>
					<td>
						<input id="zweiseiten_options[zs_facebook_url]" class="regular-text" type="text" name="zweiseiten_options[zs_facebook_url]" value="<?php esc_attr_e( $options['zs_facebook_url'] ); ?>" />
						<label class="description" for="zweiseiten_options[zs_facebook_url]"><?php _e( 'Enter your Facebook URL.', 'zwei-seiten' ); ?></label>
					</td>
				</tr>
				
				<tr valign="top"><th scope="row"><?php _e( 'Google+', 'zwei-seiten' ); ?></th>
					<td>
						<input id="zweiseiten_options[zs_gplus_url]" class="regular-text" type="text" name="zweiseiten_options[zs_gplus_url]" value="<?php esc_attr_e( $options['zs_gplus_url'] ); ?>" />
						<label class="description" for="zweiseiten_options[zs_gplus_url]"><?php _e( 'Enter your Google+ URL.', 'zwei-seiten' ); ?></label>
					</td>
				</tr>
				
				<tr valign="top"><th scope="row"><?php _e( 'Flickr', 'zwei-seiten' ); ?></th>
					<td>
						<input id="zweiseiten_options[zs_flickr_url]" class="regular-text" type="text" name="zweiseiten_options[zs_flickr_url]" value="<?php esc_attr_e( $options['zs_flickr_url'] ); ?>" />
						<label class="description" for="zweiseiten_options[zs_flickr_url]"><?php _e( 'Enter your Flickr URL.', 'zwei-seiten' ); ?></label>
					</td>
				</tr>
				
				<tr valign="top"><th scope="row"><?php _e( 'LinkedIn', 'zwei-seiten' ); ?></th>
					<td>
						<input id="zweiseiten_options[zs_linkedin_url]" class="regular-text" type="text" name="zweiseiten_options[zs_linkedin_url]" value="<?php esc_attr_e( $options['zs_linkedin_url'] ); ?>" />
						<label class="description" for="zweiseiten_options[zs_linkedin_url]"><?php _e( 'Enter your LinkedIn URL.', 'zwei-seiten' ); ?></label>
					</td>
				</tr>
				
				<?php
				/**
				 * Footer Text
				 */
				?>
				<tr valign="top"><th scope="row"><?php _e( 'Footer Text', 'zwei-seiten' ); ?></th>
					<td>
						<input id="zweiseiten_options[zs_footer_text]" class="regular-text" type="text" name="zweiseiten_options[zs_footer_text]" value="<?php esc_attr_e( $options['zs_footer_text'] ); ?>" />
						<label class="description" for="zweiseiten_options[zs_footer_text]"><?php _e( 'Type here any text which will be displayed in the footer.', 'zwei-seiten' ); ?></label>
					</td>
				</tr>

				<?php
				/**
				 * Custom CSS
				 */
				?>
				<tr valign="top"><th scope="row"><?php _e( 'Custom CSS', 'zwei-seiten' ); ?></th>
					<td>
						<textarea id="zweiseiten_options[zs_custom_css]" class="large-text" cols="50" rows="10" name="zweiseiten_options[zs_custom_css]"><?php echo esc_textarea( $options['zs_custom_css'] ); ?></textarea>
						<label class="description" for="zweiseiten_options[zs_custom_css]"><?php _e( 'Put here any CSS code.', 'zwei-seiten' ); ?></label>
					</td>
				</tr>
			</table>
			
			<?php submit_button( __('Save Settings', 'zwei-seiten'), 'primary'); ?>
		</form>
	</div>
	<?php
}

/**
 * Sanitize and validate input. Accepts an array, return a sanitized array.
 */
function zweiseiten_options_validate($input) {
	
	if ( !isset($input['zs_search_on']) )
		$input['zs_search_on'] = null;
	$input['zs_search_on'] = ($input['zs_search_on'] == 1 ? 1 : 0 );

	$input['zs_rss_url'] = esc_url_raw($input['zs_rss_url']);
	$input['zs_twitter_url'] = esc_url_raw($input['zs_twitter_url']);
	$input['zs_facebook_url'] = esc_url_raw($input['zs_facebook_url']);
	$input['zs_gplus_url'] = esc_url_raw( $input['zs_gplus_url']);
	$input['zs_flickr_url'] = esc_url_raw( $input['zs_flickr_url']);
	$input['zs_linkedin_url'] = esc_url_raw( $input['zs_linkedin_url']);
	$input['zs_footer_text'] = wp_filter_nohtml_kses($input['zs_footer_text']);
	$input['zs_custom_css'] = wp_filter_post_kses($input['zs_custom_css']);

	return $input;
}

// Based on http://themeshaper.com/2010/06/03/sample-theme-options/
// adapted from http://planetozh.com/blog/2009/05/handling-plugins-options-in-wordpress-28-with-register_setting/
